@@ -7,7 +7,7 @@ from redis.exceptions import ResponseError
 from . import models
 from icecream import ic
 from .models import LIST, VAL, StarterModel
-from limeutils import byte_conv, ValidationError
+from limeutils import byte_conv, ValidationError, listify
 
 
 
@@ -24,18 +24,30 @@ class Red(Redis):
     
     def formatkey(self, key: str) -> str:
         """
-        Create the final key name with prefix and/or version
+        Create the final key name with prefix and/or version if necessary
         :param key: The key to format
         :return:    str
         """
         pre = self.pre.strip()
         ver = self.ver.strip()
+        
+        # Prevent multiple formatting which would be bad
+        ll = key.split(':')
+        if pre and ver:
+            if ll[0] == pre and ll[1] == ver:
+                return key
+        elif pre and not ver:
+            if ll[0] == pre:
+                return key
+        elif not pre and ver:
+            if ll[0] == ver:
+                return key
+
+        ll = [pre, ver, key]
+        ll = list(filter(None, ll))
+        return ":".join(ll)
 
-        list_ = [pre, ver, key]
-        list_ = list(filter(None, list_))
-        return ":".join(list_)
 
-    # TODO: How can they change the datatype if the datatype is set by the existing variable?
     def set(self, key: str, val: Union[VAL, LIST, set, dict], **kwargs):
         """
         Set and updates a key
@@ -89,10 +101,11 @@ class Red(Redis):
             return ret
     
     
-    def get(self, key: str, **kwargs):
+    def get(self, key: str, default=None, **kwargs):
         """
         Get the value of a key
         :param key:     Key name
+        :param default: Default value if key doesn't exist
         :param kwargs:  Checks for start, end, only, and parent kwargs
         :return:        Depends on the type of key
         """
@@ -124,13 +137,31 @@ class Red(Redis):
         elif datatype == 'set':
             data = super().smembers(key)
             return {byte_conv(v) for v in data}
+        return default
 
 
     def exists(self, *keys) -> int:
+        """
+        Checks if keys exists. Returns the number of keys that exist not which of the keys exists.
+        :param keys:    Names of keys
+        :return:        int No. of keys that exist
+        """
+        for i in keys:
+            pass
         keys = [self.formatkey(i) for i in keys]
         return super().exists(*keys)
     
     
+    def delete(self, *keys):
+        """
+        Delete keys
+        :param keys:    Keys to delete
+        :return:        int Number of keys deleted
+        """
+        keys = list(map(self.formatkey, keys))
+        return super().delete(*keys)
+
+    
     def _get_type(self, key: str):
         return byte_conv(super().type(key))
 
