@@ -1,4 +1,5 @@
 from typing import Optional, Union
+from ast import literal_eval
 
 
 def isfloat(val: Union[int, float, str]):
@@ -50,6 +51,8 @@ def parse_str(string: str):
         return int(string)
     elif isfloat(string):
         return float(string)
+    elif string in ['True', 'False']:
+        return literal_eval(string)
     return string
 
 
@@ -111,15 +114,31 @@ def oxford_comma(sequence: Union[list, tuple, set], separator: str = 'or'):
         return '{}, {} {}'.format(', '.join(sequence[:-1]), separator, sequence[-1])
     
     
-def listify(data: Union[str, list, set, tuple]) -> list:
+def listify(data: Union[str, int, float, list, set, tuple, bool]) -> list:
     """
-    A convenience function that converts data into a list unless it's already a list.
-    :param data:    Data to check if it needs to be casted as a list
+    A convenience function that converts data into a list unless it's already one.
+    Bool is a subset of int.
+    :param data:    Data to turn into a list
     :return:        list
     """
-    if isinstance(data, str):
-        return [data]
+    if isinstance(data, list):
+        return data
     elif isinstance(data, (set, tuple)):
         return list(data)
     else:
-        return data
+        return [data]
+
+
+# TESTME: Untested
+def valid_str_only(item, allow_bool: bool = False) -> bool:
+    """
+    Removes empty strings and other invalid values passed that aren't valid strings.
+    :param item:        Check if valid str
+    :param allow_bool:  Allow the use of bool only if True
+    :return:            bool
+    """
+    if isinstance(item, str) and len(item) > 0:
+        return True
+    if allow_bool and item:
+        return True
+    return False
\ No newline at end of file
